<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

use Teknisa\CNC\Utilities\UtilCNC;

use Teknisa\CNC\Services\Cnc02300StatusVendasService;

class Cnc02300StatusVendas {
    protected $dataSourceName = 'cnc02300_status_venda_grafico';
    
    public function __construct(UtilCNC $util, Cnc02300StatusVendasService $service) {
        $this->util = $util;
        $this->service = $service;
    }
    
    public function getStatusVendas (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            
            $params["NRORG"]        = $this->util->getParamValueFromFilter($filter, "NRORG");
            $params["NRESTABELEC"]  = $this->util->getParamValueFromFilter($filter, "NRESTABELEC");
            $params["NRPRODUTOADQ"] = $this->util->getParamValueFromFilter($filter, "NRPRODUTOADQ");
            $params["DTVENDA"]      = $this->util->getParamValueFromFilter($filter, "DTVENDA");
            $params["NRESTABELEC"] = is_array($params["NRESTABELEC"]) ? 
                $this->util->buildParamValue($params["NRESTABELEC"]) : null;
            $params["NRPRODUTOADQ"] = is_array($params["NRPRODUTOADQ"]) ? 
                $this->util->buildParamValue($params["NRPRODUTOADQ"]) : null;
                
            $params["TNRESTABELEC"]  = $params["NRESTABELEC"] ? null : "T";
            $params["TNRPRODUTOADQ"] = $params["NRPRODUTOADQ"] ? null : "T";
            
            $dataset = $this->service->getStatusVendas($params);
            $response->addDataSet(new DataSet("cnc02300_status_venda_grafico", $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getStatusVendasDetails (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            
            $params["NRORG"]        = $this->util->getParamValueFromFilter($filter, "NRORG");
            $params["NRESTABELEC"]  = $this->util->getParamValueFromFilter($filter, "NRESTABELEC");
            $params["NRPRODUTOADQ"] = $this->util->getParamValueFromFilter($filter, "NRPRODUTOADQ");
            $params["DTVENDA"]      = $this->util->getParamValueFromFilter($filter, "DTVENDA");
            
            $params["NRESTABELEC"] = is_array($params["NRESTABELEC"]) ? 
                $this->util->buildParamValue($params["NRESTABELEC"]) : null;
            $params["NRPRODUTOADQ"] = is_array($params["NRPRODUTOADQ"]) ? 
                $this->util->buildParamValue($params["NRPRODUTOADQ"]) : null;
                
            $params["TNRESTABELEC"]  = $params["NRESTABELEC"] ? null : "T";
            $params["TNRPRODUTOADQ"] = $params["NRPRODUTOADQ"] ? null : "T";
            
            $dataset = $this->service->getStatusVendasDetails($params);
            $response->addDataSet(new DataSet("cnc02300_status_vendas_details", $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}