<?php

namespace Teknisa\CNC\Factories;

use Doctrine\ORM\EntityManager;

class Cnc01700ParametrizacaoProdutoFactory {
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function findEstabelec($params){
        $sql = "SELECT NRESTABELEC, CDESTABELEC, NMESTABELEC, CDEMPRESA, CDINSCESTA, CDINSCMUNI, CDSERIE
                    FROM ESTABELECIMENTO";     
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getEstabelecSerie ($params) {
        
        $sql = "SELECT DISTINCT CDINSCESTA, CDINSCMUNI, CDSERIE, DSSERIE  
                    FROM SERIENF
                    WHERE NRORG = :NRORG  
                     AND CDINSCESTA = :CDINSCESTA  
                     AND CDINSCMUNI = :CDINSCMUNI  
                     AND CDEMPRESA = :CDEMPRESA  
                    ORDER BY CDSERIE";        
        $std = $this->connection->prepare($sql);
        
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function saveCliente($params){
        $sql = "UPDATE ADQUIRENTE
                SET CDCLIENTE = :CDCLIENTE,
                    CDTPDBDEBGER = :CDTPDBDEBGER,
                    CDTPCREDBANCGER = :CDTPCREDBANCGER,
                    IDGERAFINANC = :IDGERAFINANC
                WHERE NRORG = :NRORG
                 AND NRADQUIRENTE = :NRADQUIRENTE ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function produtoTab($params){
        
        $sql = "SELECT P.NRPARAMFINADQ, P.NRESTABELEC, E.NMESTABELEC, P.NRADQUIRENTE, P.CDTPCTRECEB,
                  TCR.DSTPCTRECEB, P.CDAJUCTREC, TAR.DSAJUCTREC, P.CDTPCREDBANC,
                  TDC.DSTPCREDBANC, P.NRORG, P.CDTIPOOPER, TOA.NMTIPOOPER,
                  P.NRPRODUTOADQ, P.IDENTRSAIDOP, PR.NMPRODUTOADQ, P.CDTPDEBIBANC, TPD.DSTPDEBIBANC
                FROM PARAMFINADQ P
                  LEFT JOIN TIPOCTRECEBER TCR
                   ON P.CDTPCTRECEB = TCR.CDTPCTRECEB
                  LEFT JOIN TIPOAJRECEBER TAR
                   ON P.CDAJUCTREC = TAR.CDAJUCTREC
                  LEFT JOIN TPCREDBANC TDC
                   ON P.CDTPCREDBANC = TDC.CDTPCREDBANC
                  LEFT JOIN TIPOOPERAC TOA
                   ON P.CDTIPOOPER = TOA.CDTIPOOPER
                   AND P.IDENTRSAIDOP = TOA.IDENTRSAIDOP 
                  LEFT JOIN ESTABELECIMENTO E
                   ON P.NRESTABELEC = E.NRESTABELEC
                  LEFT JOIN PRODUTOADQ PR
                   ON P.NRPRODUTOADQ = PR.NRPRODUTOADQ
                  LEFT JOIN TPDEBIBANC TPD
                   ON P.CDTPDEBIBANC = TPD.CDTPDEBIBANC
                WHERE P.NRORG = :NRORG
                  AND P.NRADQUIRENTE = :NRADQUIRENTE
                  AND P.NRESTABELEC IS NULL
                  AND ( INSTR(PR.NMPRODUTOADQ, UPPER(:ALL_FIELDS)) <> 0 OR (:TALL_FIELDS = 'T') )
                  ";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    public function saveNewProdutoParams($params){
        $sql = "INSERT INTO PARAMFINADQ
                (NRPARAMFINADQ, NRADQUIRENTE, NRPRODUTOADQ, NRESTABELEC, CDTPCTRECEB, CDAJUCTREC,
                CDTIPOOPER, IDENTRSAIDOP, CDTPCREDBANC, NRORG, CDTPDEBIBANC)
                VALUES
                (:NRPARAMFINADQ, :NRADQUIRENTE, :NRPRODUTOADQ, :NRESTABELEC, :CDTPCTRECEB, :CDAJUCTREC, 
                :CDTIPOOPER, :IDENTRSAIDOP, :CDTPCREDBANC, :NRORG, :CDTPDEBIBANC)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }

    public function saveNewEstabelecParams($params){
        $sql = "INSERT INTO PARAMFINADQ
                (NRPARAMFINADQ, NRADQUIRENTE, NRPRODUTOADQ, NRESTABELEC, CDTPCTRECEB, CDAJUCTREC,
                CDTIPOOPER, IDENTRSAIDOP, CDTPCREDBANC, NRORG, CDTPDEBIBANC)
                VALUES
                (:NRPARAMFINADQ, :NRADQUIRENTE, :NRPRODUTOADQ, :NRESTABELEC, :CDTPCTRECEB, :CDAJUCTREC, 
                :CDTIPOOPER, :IDENTRSAIDOP, :CDTPCREDBANC, :NRORG, :CDTPDEBIBANC)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }

    
    public function saveProdutoParamsEdit($params){

        $sql = "UPDATE PARAMFINADQ
                SET NRPRODUTOADQ = :NRPRODUTOADQ,
                    CDTPCTRECEB = :CDTPCTRECEB,
                    CDAJUCTREC = :CDAJUCTREC,
                    CDTIPOOPER = :CDTIPOOPER,
                    IDENTRSAIDOP = :IDENTRSAIDOP,
                    CDTPCREDBANC = :CDTPCREDBANC,
                    CDTPDEBIBANC = :CDTPDEBIBANC
                WHERE NRORG = :NRORG
                  AND NRADQUIRENTE = :NRADQUIRENTE
                  AND  NRPARAMFINADQ = :NRPARAMFINADQ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function editEstabelec($params){
        $sql = "UPDATE PARAMFINADQ
                SET NRESTABELEC = :NRESTABELEC,
                    CDTPCTRECEB = :CDTPCTRECEB,
                    CDAJUCTREC = :CDAJUCTREC,
                    CDTIPOOPER = :CDTIPOOPER,
                    IDENTRSAIDOP = :IDENTRSAIDOP,
                    CDTPCREDBANC = :CDTPCREDBANC,
                    CDTPDEBIBANC = :CDTPDEBIBANC
                WHERE NRORG = :NRORG
                  AND NRPRODUTOADQ = :NRPRODUTOADQ
                  AND NRADQUIRENTE = :NRADQUIRENTE
                  AND NRESTABELEC = :NRESTABELECANT";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getTpCredito () {
        $sql = "SELECT CDTPCREDBANC, DSTPCREDBANC FROM TPCREDBANC ORDER BY CDTPCREDBANC";        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function getTpOper(){
        $sql = "SELECT DISTINCT CDTIPOOPER, NMTIPOOPER, IDENTRSAIDOP FROM TIPOOPERAC WHERE IDENTRSAIDOP = 'S' 
                ORDER BY CDTIPOOPER";        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getContaRec () {
        $sql = "SELECT CDTPCTRECEB, DSTPCTRECEB FROM TIPOCTRECEBER ORDER BY CDTPCTRECEB";        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getTpAjuste(){
        $sql = "SELECT CDAJUCTREC, DSAJUCTREC FROM TIPOAJRECEBER WHERE IDAJUCTREC = 'D' ORDER BY CDAJUCTREC";        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getTpDebito () {
        $sql = "SELECT CDTPDEBIBANC, CDTPDEBIBANC CDTPDEBALUGUEL, CDTPDEBIBANC CDTPDBDEBGER,
                DSTPDEBIBANC, DSTPDEBIBANC DSTPDEBALUGUEL, DSTPDEBIBANC DSTPDBDEBGER
                FROM TPDEBIBANC ORDER BY CDTPDEBIBANC";        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function deleteProduto($params){
        $sql = "DELETE FROM PARAMFINADQ
                WHERE NRORG = :NRORG
                  AND NRADQUIRENTE = :NRADQUIRENTE
                  AND NRPRODUTOADQ = :NRPRODUTOADQ";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteEstabelec($params){
        $sql = "DELETE FROM PARAMFINADQ
                WHERE NRORG = :NRORG
                  AND NRADQUIRENTE = :NRADQUIRENTE
                  AND NRPARAMFINADQ = :NRPARAMFINADQ
                  AND NRESTABELEC = :NRESTABELEC
                  AND NRPRODUTOADQ = :NRPRODUTOADQ";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteEstabelecFromProdutoEdit($params){
        $sql = "DELETE FROM PARAMFINADQ
                WHERE NRORG = :NRORG
                  AND NRADQUIRENTE = :NRADQUIRENTE
                  AND NRPRODUTOADQ = :NRPRODUTOADQ
                  AND NRESTABELEC IS NOT NULL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function findProdutoExist($params){
        $sql = "SELECT NRPARAMFINADQ FROM PARAMFINADQ
                WHERE NRORG = :NRORG
                  AND NRADQUIRENTE = :NRADQUIRENTE
                  AND NRPRODUTOADQ = :NRPRODUTOADQ
                  AND NRESTABELEC IS NULL";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetchAll();
    }
    
    public function filterEstabelec($params){
        $sql = "SELECT NRESTABELEC FROM PARAMFINADQ
                WHERE NRORG = :NRORG
                  AND NRADQUIRENTE = :NRADQUIRENTE
                  AND NRPRODUTOADQ = :NRPRODUTOADQ
                  AND NRESTABELEC IS NOT NULL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function findEstabelecExist($params){
        $sql = "SELECT NRPARAMFINADQ FROM PARAMFINADQ
                WHERE NRADQUIRENTE = :NRADQUIRENTE
                  AND NRPRODUTOADQ = :NRPRODUTOADQ
                  AND NRESTABELEC = :NRESTABELEC
                  AND NRORG  = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetchAll();
    }
    
    public function getProdutoEstabelec($params){
        $sql = "SELECT P.NRPARAMFINADQ, P.NRESTABELEC, E.NMESTABELEC, P.NRADQUIRENTE, P.CDTPCTRECEB,
                  TCR.DSTPCTRECEB, P.CDAJUCTREC, TAR.DSAJUCTREC, P.CDTPCREDBANC,
                  TDC.DSTPCREDBANC, P.NRORG, P.CDTIPOOPER, TOA.NMTIPOOPER,
                  P.NRPRODUTOADQ, P.IDENTRSAIDOP, PR.NMPRODUTOADQ, E.CDESTABELEC, TPD.DSTPDEBIBANC,
                  P.CDTPDEBIBANC
                FROM PARAMFINADQ P
                  LEFT JOIN TIPOCTRECEBER TCR
                   ON P.CDTPCTRECEB = TCR.CDTPCTRECEB
                  LEFT JOIN TIPOAJRECEBER TAR
                   ON P.CDAJUCTREC = TAR.CDAJUCTREC
                  LEFT JOIN TPCREDBANC TDC
                   ON P.CDTPCREDBANC = TDC.CDTPCREDBANC
                  LEFT JOIN TIPOOPERAC TOA
                   ON P.CDTIPOOPER = TOA.CDTIPOOPER
                   AND P.IDENTRSAIDOP = TOA.IDENTRSAIDOP 
                  LEFT JOIN ESTABELECIMENTO E
                   ON P.NRESTABELEC = E.NRESTABELEC
                  LEFT JOIN TPDEBIBANC TPD
                   ON P.CDTPDEBIBANC = TPD.CDTPDEBIBANC
                  LEFT JOIN PRODUTOADQ PR
                   ON P.NRPRODUTOADQ = PR.NRPRODUTOADQ
                WHERE P.NRORG = :NRORG
                  AND P.NRADQUIRENTE = :NRADQUIRENTE
                  AND P.NRPRODUTOADQ = :NRPRODUTOADQ
                  AND P.NRESTABELEC IS NOT NULL
                  AND ( INSTR(E.CDESTABELEC || '_' || E.NMESTABELEC, UPPER(:ALL_FIELDS)) <> 0 OR (:TALL_FIELDS = 'T') )
               ORDER BY E.CDESTABELEC";
               
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetchAll();
    }

}
