<?php

namespace Teknisa\CNC\Factories;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

use Doctrine\ORM\EntityManager;

class Cnc02200ErrorLogFactory {
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function findAll ($params) {
        $sql = "SELECT L.NRLOGERROCTBCNC, TO_CHAR(L.DTINICIAL, 'DD/MM/YYYY') DTINICIAL, TO_CHAR(L.DTFINAL, 'DD/MM/YYYY') DTFINAL, L.DSERRO, L.DSSOLUCAO, L.NRESTABELEC, E.NMESTABELEC, L.NRORG 
                FROM LOGERROCTBCNC L, ESTABELECIMENTO E 
                WHERE L.NRORG = :NRORG
                  AND L.NRESTABELEC = E.NRESTABELEC
                  AND L.IDVISIVEL = 'S'
                ORDER BY L.DTINICIAL, L.DTFINAL, NRESTABELEC, NMESTABELEC";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function find ($params) {
        $sql = "SELECT L.NRLOGERROCTBCNC, TO_CHAR(L.DTINICIAL, 'DD/MM/YYYY') DTINICIAL, TO_CHAR(L.DTFINAL, 'DD/MM/YYYY') DTFINAL, L.DSERRO, L.DSSOLUCAO, L.NRESTABELEC, E.CDESTABELEC, E.NMESTABELEC, L.NRORG
                FROM LOGERROCTBCNC L, ESTABELECIMENTO E 
                WHERE L.NRORG = :NRORG
                  AND ((INSTR (:NRESTABELEC, '|'||TO_CHAR(L.NRESTABELEC)||'|') > 0) OR ('T' = :NRESTABELEC))
                  AND L.NRESTABELEC = E.NRESTABELEC
                  AND L.IDVISIVEL = 'S'
                ORDER BY L.DTINICIAL, L.DTFINAL, NRESTABELEC, NMESTABELEC";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getDateFromErrorLog ($params) {
        $sql = "SELECT MIN (DISTINCT DTINICIAL) DTINICIAL, MAX (DISTINCT DTFINAL) DTFINAL
                FROM LOGERROCTBCNC
                WHERE NRORG = :NRORG
                  AND NRESTABELEC = :NRESTABELEC
                  AND IDVISIVEL = 'S'";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll()[0];
    }
    
    public function runProcFinanc ($row) {
        $storedProcedure = new StoredProcedure($this->connection, 'GERA_FINANCEIRO_CNC');

        $storedProcedure->addParam(new Param('P_SEQESTABELEC', Param::PARAM_INPUT, $row['NRESTABELEC'], Param::PARAM_TYPE_STR));
        $storedProcedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $row['DTINICIAL'], Param::PARAM_TYPE_STR));
        $storedProcedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $row['DTFINAL'], Param::PARAM_TYPE_STR));
        $storedProcedure->execute();
    }
    
    public function countErrors ($params) {
        $sql = "SELECT COUNT(*) COUNT
                FROM LOGERROCTBCNC L
                WHERE L.NRORG = :NRORG
                  AND ((INSTR (:NRESTABELEC, '|'||TO_CHAR(L.NRESTABELEC)||'|') > 0))
                  AND L.IDVISIVEL = 'S'";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll()[0]["COUNT"];
    }
    
    public function countErrorsForCard ($params) {
        $sql = "SELECT COUNT(*) COUNT
                FROM LOGERROCTBCNC
                WHERE NRORG = :NRORG
                AND IDVISIVEL = 'S'";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll()[0]["COUNT"];
    }
    
} 