<?php

namespace Teknisa\CNC\Services;

use Teknisa\CNC\Factories\Cnc00800CompVendasFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\CNC\Utilities;

class Cnc00800CompVendasService {

    protected $entityManager;
    protected $environment;
    protected $util;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager,Environment $environment, Cnc00800CompVendasFactory $factory, Utilities\UtilCNC $util) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->factory = $factory;
        $this->util  = $util;
    }
    
    public function getValoresVendas ($conditions) {
        return $this->factory->getValoresVendas(array(
            ':NRESTABELEC'      => $conditions['NRESTABELEC'],
            ':TNRESTABELEC'     => $conditions['TNRESTABELEC'],
            ':NRADQUIRENTE'     => $conditions['NRADQUIRENTE'],
            ':TNRADQUIRENTE'    => $conditions['TNRADQUIRENTE'],
            ':NRPRODUTOADQ'     => $conditions['NRPRODUTOADQ'],
            ':TNRPRODUTOADQ'    => $conditions['TNRPRODUTOADQ'],
            ':NRBANDEIRAVAN'    => $conditions['NRBANDEIRAVAN'],
            ':TNRBANDEIRAVAN'   => $conditions['TNRBANDEIRAVAN'],
            ':DTVENDAINI'       => $conditions['DTVENDAINI'],
            ':DTVENDAFIN'       => $conditions['DTVENDAFIN'],
            ':TIPODATA'         => $conditions['PERIODO']
        ));
    }
    
    public function concatParams($paramsArray) {
        $paramsStr = '';
        foreach ($paramsArray as $param)
            $paramsStr = $paramsStr.$param.'|';
            
        return '|'.$paramsStr;
    }
    
    public function formatAndValidateMonthRows ($conditions) {
        $dateIni = explode('/', $conditions['DTVENDAINI']);
        $dateFin = explode( '/', $conditions['DTVENDAFIN']);
        
        $inicialDate    = date_create($dateIni[1].'/'.$dateIni[0].'/'.'01');
        $finalDate      = date_create($dateFin[1].'/'.$dateFin[0].'/'.(date('t', strtotime($dateFin[1].'-'.$dateFin[0].'-1'))));
        $dateDiference = $finalDate->diff($inicialDate);
        
        if($dateIni[1] > $dateFin[1])
            throw new \Exception('INVALID_YEAR', 2);
        if ($dateIni[0] > $dateFin[0] && $dateIni[1] >= $dateFin[1])
            throw new \Exception('INVALID_MONTH', 1);
        if ($dateDiference->y != 0)
            throw new \Exception('INVALID_YEAR_MONTH_PERIOD', 3);
        
        $formatedDates = [];
        
        $formatedDates[0] = date('01/'.$dateIni[0].'/'.$dateIni[1]);
        $formatedDates[1] = date((date('t', strtotime($dateFin[1].'-'.$dateFin[0].'-1'))).'/'.$dateFin[0].'/'.$dateFin[1]);
        
        return $formatedDates;
    }
    
    public function validateDayPeriodRow (&$conditions) {
        $dateIni = explode('/', $conditions['DTVENDAINI']);
        $dateFin = explode('/', $conditions['DTVENDAFIN']);
        
        $inicialDate    = date_create($dateIni[2].'/'.$dateIni[1].'/'.$dateIni[0]);
        $finalDate      = date_create($dateFin[2].'/'.$dateFin[1].'/'.$dateFin[0]);
        $dateDiference  = $finalDate->diff($inicialDate);
        
        if ($dateDiference->d > 14)
            throw new \Exception('INVALID_DAY_PERIOD', 4);
    }

    public function getValoresVendasDetails($conditions) {
        return $this->factory->getValoresVendasDetails($conditions);
    }
}