<?php

namespace Teknisa\CNC\Services;

use Teknisa\Libs\Util\Environment;

use Teknisa\CNC\Utilities\UtilCNC;

use Teknisa\CNC\Factories\Cnc03100DesconciliacaoVendasFactory;

class Cnc03100DesconciliacaoVendasService {
    protected $entityManager;
    protected $environment;
    protected $factory;
    protected $util;
    
    public function __construct (\Doctrine\ORM\EntityManager $entityManager,Environment $environment, Cnc03100DesconciliacaoVendasFactory $factory, UtilCNC $util) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->factory = $factory;
        $this->util = $util;
    }
    
    public function selectConciliacoes ($filter) {
        if ($this->util->compareDates($filter['DTVENDA'][0], $filter['DTVENDA'][1]))
            throw new \Exception("MOUNTH_INTERVAL", 1);
        if(isset($filter["ISEQUAL"])){
            if ($filter["ISEQUAL"] == false)
            throw new \Exception("IS_EQUAL_FILIAL", 2);
        }
        $datasets[] = $this->conciliacoesSelect($filter);
        return $datasets;
    }
    
    public function conciliacoesSelect ($filter) {
        $params = array(
                ":NRORG"        => $filter["NRORG"],
                ":NRESTABELEC"  => $filter["NRESTABELEC"],
                ":TNRESTABELEC" => $filter["TNRESTABELEC"],
                ":NRPRODUTOADQ" => $filter["NRPRODUTOADQ"],
                ":TNRPRODUTOADQ"=> $filter["TNRPRODUTOADQ"],
                ":DTVENDA_MIN"  => $filter["DTVENDA"][0],
                ":DTVENDA_MAX"  => $filter["DTVENDA"][1],
                ":CDNSU"        => $filter["CDNSU"],
                ":TCDNSU"       => $filter["TCDNSU"]);
        
        return $this->factory->conciliacoesSelect($params);
    }
    
    public function verificaConciliacoesSimultaneas ($params) {
        return $this->factory->verificaConciliacoesSimultaneas(array(
            ":NRCONCLANC" => $params["NRCONCLANC"]
        ));
    }
    
    public function verifyContReceb ($params) {
        return $this->factory->verifyContReceb(array(
            ":CDFILIAL"     => $params["CDFILIAL"],
            ":NRLANCTONF"   => $params["NRLANCTONF"]
        ));
    }
    
    public function getDatasVendas ($params) {
        $array = array(":NRCONCLANC" => $params["NRCONCLANC"]);
        
        return $this->factory->getDatasVendas($array);
    }
    
    public function deleteItemCorVenda ($NRCONSMOVCAIXA) {
        return $this->factory->deleteItemCorVenda(array(
            ":NRCONSMOVCAIXA" => $NRCONSMOVCAIXA
        ));
    }
    
    public function desconciliacaoVendas ($params) {
        $bool = true;
        
        $isPgtoConc = false;
        $concPagamentos = $params["NRCONCLANCPGTO"];
        if (!is_null($concPagamentos)) {
            $concPagamentos = is_array($concPagamentos) ? $concPagamentos : [$concPagamentos];
            $isPgtoConc = true;
        }
        
        if ($isPgtoConc) {
            foreach($concPagamentos as $concPgto) {
                $bool = $bool && $this->factory->nullifyRowsAtRetFinancAdq(array(
                    ":NRORG"        => $params["NRORG"],
                    ":NRCONCLANC"   => $concPgto
                ));
            }
        }
        
        $bool = $bool && $this->factory->nullifyRowsAtRetVendaAdq(array(
            ":NRORG"        => $params["NRORG"],
            ":NRCONCLANC"   => $params["NRCONCLANC"]
        ));
        
        $bool = $this->factory->nullifyRowsAtConsMovCaixa(array(
            ":NRORG"        => $params["NRORG"],
            ":NRCONCLANC"   => $params["NRCONCLANC"],
            ":CDFILIAL"     => $params["CDFILIAL"]
        ));
        
        //deleta a conciliacaolanc
        $bool = $bool && $this->factory->deleteFromConciliacaoLanc(array(
            ":NRORG"        => $params["NRORG"],
            ":NRCONCLANC"   => $params["NRCONCLANC"]
        ));
        
        //deleta a conciliacaolanc
        if ($isPgtoConc) {
            foreach ($concPagamentos as $concPgto) {
                $bool = $bool && $this->factory->deleteFromConciliacaoLanc(array(
                    ":NRORG"        => $params["NRORG"],
                    ":NRCONCLANC"   => $concPgto
                ));
            }
        }
        
        // deleta a divconciliacao com o conclanc
        $bool = $bool && $this->factory->deleteFromDivConciliacaoConvmovcaixa(array(
            ":NRORG"          => $params["NRORG"],
            ":NRCONSMOVCAIXA" => $params["NRCONSMOVCAIXA"]
        ));
        
        // deleta a divconciliacao com o conclanc para a retfinancadq
        if ($isPgtoConc) {
            foreach ($concPagamentos as $concPgto) {
                $bool = $bool && $this->factory->deleteFromDivConciliacao(array(
                    ":NRORG"        => $params["NRORG"],
                    ":NRCONCLANC"   => $concPgto
                ));
            }
        }
        
        $bool = $this->factory->updateMovCaixa(array(
            ":CDFILIAL"   => $params["CDFILIAL"],
            ":CDCAIXA"    => $params["CDCAIXA"],
            ":NRSEQUMOVI" => $params["NRSEQUMOVI"],
            ":DTABERCAIX" => $params["DTABERCAIX"]
        ));
        
        return $bool;
    }
    
    public function deletaFinanceiro ($params) {
        $bool = true;
        
        $contaReceber = $this->factory->verifyContaReceberInfo(array(
            ":NRLANCTONF" => $params["NRLANCTONF"],
            ":CDFILIAL"   => $params["CDFILIAL"]
        ));
        
        $boletoReceber = $this->factory->verifyBoletReceberInfo(array(
            ":CDFILIBOLREC" => $contaReceber["CDFILIBOLREC"],
            ":NRLANBOLREC"  => $contaReceber["NRLANBOLREC"]
        ));
        
        $verifyBoletConta = $this->factory->verifyBoletConta(array(
            ':NRLANBOLREC' =>  $boletoReceber['NRLANBOLREC'],
            ':CDFILIAL'    =>  $params['CDFILIAL']
        ));
        
        $VRFINALBREC = $boletoReceber['VRFINALBREC'] - $contaReceber['VRATUAREC'];
        
        if (($verifyBoletConta['TOT'] == '1') || ($verifyBoletConta['TOT'] == NULL) || ($verifyBoletConta == false) || ((float)$verifyBoletConta['TOT'] == 1)) {
            
            //Remove o boleto da Conta
            $bool = $bool && $this->factory->nullifyBoletContaReceber(array(
                ":NRLANCTONF" => $params["NRLANCTONF"],
                ":CDFILIAL"   => $params["CDFILIAL"]
            ));
            
             // Deleta o tipo de recebimento do Boleto
            $bool = $this->factory->deleteTipoReceBoletReceber(array(
                ":CDFILIAL"     => $contaReceber["CDFILIBOLREC"],
                ":NRLANBOLREC"  => $contaReceber["NRLANBOLREC"]
            ));
            
            // Deleta Boleto, pois só existe uma Conta associada
            $bool = $this->factory->deleteBoletReceber(array(
                ":CDFILIAL"     => $contaReceber["CDFILIBOLREC"],
                ":NRLANBOLREC"  => $contaReceber["NRLANBOLREC"]
            ));
            
            // Deleta Ajuste da Conta a Receber
            $bool = $this->factory->deleteAjCtReceber(array(
                ":NRLANCTONF" => $params["NRLANCTONF"],
                ":CDFILIAL"   => $params["CDFILIAL"]
            ));
            
            // Deleta o Conta a Receber
            $bool = $this->factory->deleteCtReceber(array(
                ":NRLANCTONF" => $params["NRLANCTONF"],
                ":CDFILIAL"   => $params["CDFILIAL"]
            ));
            
            // Atualiza a CONSMOVCAIXA retirando informações Financeiras
            $bool = $this->factory->updateFinancConsMovCaixa(array(
                ":CDFILIAL"        => $params["CDFILIAL"],
                ":NRCONSMOVCAIXA"  => $params["NRCONSMOVCAIXA"]
            ));
            
            // Deleta Nota Fiscal
            $bool = $this->factory->deleteNotaFiscal(array(
                ":NRLANCTONF" => $params["NRLANCTONF"],
                ":CDFILIAL"   => $params["CDFILIAL"]
            ));
        } else if ((((float)$verifyBoletConta['TOT'] > 1))) {
            
            //Remove o boleto da Conta
            $bool = $bool && $this->factory->nullifyBoletContaReceber(array(
                ":NRLANCTONF" => $params["NRLANCTONF"],
                ":CDFILIAL"   => $params["CDFILIAL"]
            ));
            
            $verifyBoletConta = $this->factory->verifyBoletConta(array(
                ':NRLANBOLREC' =>  $boletoReceber['NRLANBOLREC'],
                ':CDFILIAL'    =>  $params['CDFILIAL']
            ));
            
            // Atualiza o tipo de recebimento do Boleto
            $bool = $this->factory->updateTipoReceBoletReceber(array(
                ":CDFILIAL"     => $contaReceber["CDFILIBOLREC"],
                ":NRLANBOLREC"  => $contaReceber["NRLANBOLREC"],
                ":TOTBOLET"     => (float)$verifyBoletConta['TOTBOLET']
            ));
            
            // Atualiza o Boleto
            $bool = $this->factory->updateBoletReceber(array(
                ":CDFILIAL"     => $contaReceber["CDFILIBOLREC"],
                ":NRLANBOLREC"  => $contaReceber["NRLANBOLREC"],
                ":TOTBOLET"     => (float)$verifyBoletConta['TOTBOLET']
            ));
            
            // Deleta Ajuste da Conta a Receber
            $bool = $this->factory->deleteAjCtReceber(array(
                ":NRLANCTONF" => $params["NRLANCTONF"],
                ":CDFILIAL"   => $params["CDFILIAL"]
            ));
            
            // Deleta o Conta a Receber
            $bool = $this->factory->deleteCtReceber(array(
                ":NRLANCTONF" => $params["NRLANCTONF"],
                ":CDFILIAL"   => $params["CDFILIAL"]
            ));
            
            // Atualiza a CONSMOVCAIXA retirando informações Financeiras
            $bool = $this->factory->updateFinancConsMovCaixa(array(
                ":CDFILIAL"        => $params["CDFILIAL"],
                ":NRCONSMOVCAIXA"  => $params["NRCONSMOVCAIXA"]
            ));
            
            // Deleta Nota Fiscal
            $bool = $this->factory->deleteNotaFiscal(array(
                ":NRLANCTONF" => $params["NRLANCTONF"],
                ":CDFILIAL"   => $params["CDFILIAL"]
            ));
        }
        
        return $bool;
    }
    
    public function deletaConsmovcaixa($params) {
	    $param = array(
	        ':NRCONSMOVCAIXA' => $params['CHAVE']
	    );
	    return $this->factory->deleteConsMovCaixa($param);
	}
	
	public function executaReplicacao($data){
	    return $this->factory->executaReplicacao($data); 
    }
    
    public function verifyInfoConsmov ($params) {
	    $param = array(
	        ':NRCONSMOVCAIXA' => $params['CHAVE'],
	        ':NRORG'          => $params['NRORG']
	    );
	    return $this->factory->verifyInfoConsmov($param);
	}
	
    public function atualizaSistema ($params) {
        $bool = true;
        
        $movCaixaInfo = $this->factory->getMovCaixa(array(
            ":CDFILIAL"   => $params["CDFILIAL"],
            ":CDCAIXA"    => $params["CDCAIXA"],
            ":NRSEQUMOVI" => $params["NRSEQUMOVI"],
            ":DTABERCAIX" => $params["DTABERCAIX"]
        ));
        
        $diasVenc = $this->factory->calcNrDiasVenc(array(
            ":CDFILIAL"   => $params["CDFILIAL"],
            ":CDTIPORECE" => $movCaixaInfo["CDTIPORECE"]
        ))['V_NRDIASVENC'];
        
        if($diasVenc==null){
            $diasVenc = 0;
        }
                
        $dataVenc = $this->factory->verifyDataVenc(array(
            ":CDFILIAL"    => $params["CDFILIAL"],
            ":DTVENDA"     => $params["DTVENDA"],
            ":NRDIASVENC"  => $diasVenc,
            ":CDTIPORECE"  => $movCaixaInfo["CDTIPORECE"]
        ));
        
        $bool = $this->factory->updateConsMovCaixaDesconciliacao(array(
            ":NRCONSMOVCAIXA" => $params["NRCONSMOVCAIXA"],
            ":CDFILIAL"       => $params["CDFILIAL"],
            ":CDCAIXA"        => $params["CDCAIXA"],
            ":NRSEQUMOVI"     => $params["NRSEQUMOVI"],
            ":DTABERCAIX"     => $params["DTABERCAIX"],
            ":CDNSU"          => $movCaixaInfo['CDNSUHOSTTEF'],
            ":VRVENDA"        => $movCaixaInfo['VRMOVIVEND'],
            ":CDTIPORECE"     => $movCaixaInfo['CDTIPORECE'],
            ":DTVENDA"        => $movCaixaInfo['DTMOVIMCAIXA'],
            ":DTVENCIMENTO"   => $dataVenc['V_DTVENCIMENTO']
        ));
        
        return $bool;
    }
}